@@ -1,12 +1,17 @@
 # -*- coding: utf-8 -*-
 from __future__ import annotations
 
-from unittest import TestCase, main
+from unittest import TestCase
+from unittest import main
 
 from PyR3.factory.fields.Unit import Length
-from PyR3.factory.MeshFactory import MeshFactory, getfields
-from PyR3.shortcut.context import Objects, cleanScene, wipeScenes
-from PyR3.shortcut.mesh import addCylinder, addCube
+from PyR3.factory.MeshFactory import MeshFactory
+from PyR3.factory.MeshFactory import getfields
+from PyR3.shortcut.context import Objects
+from PyR3.shortcut.context import cleanScene
+from PyR3.shortcut.context import wipeScenes
+from PyR3.shortcut.mesh import addCube
+from PyR3.shortcut.mesh import addCylinder
 
 
 class TestMeshFactory(TestCase):
