@@ -1,8 +1,11 @@
 # -*- coding: utf-8 -*-
 from __future__ import annotations
-from PyR3.factory.fields.Struct import Struct
+
+from unittest import TestCase
+from unittest import main
+
 from PyR3.factory.fields.Number import Integer
-from unittest import TestCase, main
+from PyR3.factory.fields.Struct import Struct
 
 
 class TestStructField(TestCase):
